@@ -430,7 +430,7 @@ class Server:
             return '''
 <h1>Personis</h1>
 Looks like you're coming into the service entrance with a browser, which is not how this works. Ask someme about 'Mneme', or perhaps you're looking for <a href="/list_apps">your apps</a>.
-<br/>If you're an administrator, you might want to try <a href="/list_clients">the admin page</a>, or the <a href="/doc/index.html">the docs</a>.
+<br/>If you're an administrator, you might want to try <a href="/list_clients">the admin page</a>, or the <a href="http://packages.python.org/personis/">the docs</a>.
 <br/>Source at <a href="https://github.com/jbu/personis">github</a>.
 '''
         if access_token not in access_tokens:
